@@ -10,6 +10,7 @@ from ..acquisition.models import ChannelType, CampaignGoal, Campaign as Campaign
 from ..general.dataclasses import ResolvableCompanyModel
 from ..integrations.dataclasses import LinkInfo
 from ..services.clients import MSClient
+from ..vacancies.dataclasses import FeedInfo
 
 
 # Campaign object
@@ -27,6 +28,8 @@ class CampaignInfo(ResolvableCompanyModel):
     channel: LinkInfo
     channel_type: ChannelType
     campaign_goal: Optional[CampaignGoal]
+    feed: FeedInfo
+    selection_criteria: Optional[dict]
 
     @staticmethod
     async def resolve_object(object_id: UUID, organization_id: UUID) -> "CampaignInfo | None":
@@ -40,6 +43,7 @@ class CampaignInfo(ResolvableCompanyModel):
     @classmethod
     async def from_model(cls: "CampaignInfo", model: CampaignModel) -> 'CampaignInfo':
         channel = await LinkInfo.resolve_object(model.channel_id, model.organization)
+        feed = await FeedInfo.resolve_object(model.feed_id, model.organization)
 
         return cls(
             id=model.id,
@@ -54,6 +58,8 @@ class CampaignInfo(ResolvableCompanyModel):
             channel=channel,
             channel_type=model.channel_type,
             campaign_goal=model.campaign_goal,
+            feed=feed,
+            selection_criteria=model.selection_criteria
         )
 
 
@@ -71,6 +77,8 @@ class CampaignConfig(BaseModel):
     channel_id: UUID
     channel_type: ChannelType
     campaign_goal: Optional[CampaignGoal]
+    feed_id: str
+    selection_criteria: Optional[dict]
 
     @classmethod
     async def from_model(cls: "CampaignConfig", model: CampaignModel) -> 'CampaignConfig':
