@@ -1,8 +1,10 @@
 import os
+
 from datetime import datetime
-from typing import List, Optional
+from typing import List, Optional, Literal
 from uuid import UUID
 from dataclasses import field
+from pydantic.dataclasses import dataclass
 
 from httpx import AsyncClient
 from pydantic import BaseModel
@@ -19,19 +21,21 @@ class VacancyLocation(BaseModel):
     address: str | None = None
     state: str | None = None
     country: str | None = None
+    lat: float | None = None
+    lng: float | None = None
 
 
 class Salary(BaseModel):
     min: float | None = None
     max: float | None = None
-    currency: str = "EUR"
-    frequency: SalaryFrequency = "month"
+    currency: str | None = None
+    frequency: SalaryFrequency | None = None
 
 
 class Hours(BaseModel):
-    min: int = 0
-    max: int = 40
-    fte: float = 1.0
+    min: int | None = None
+    max: int | None = None
+    fte: float | None = None
 
 
 class ContactDetails(BaseModel):
@@ -96,6 +100,8 @@ class VacancyData(BaseModel):
             location_city=self.location.city,
             location_state=self.location.state,
             location_country=self.location.country,
+            location_lat=self.location.lat,
+            location_lng=self.location.lng,
             salary_min=self.salary.min,
             salary_max=self.salary.max,
             salary_currency=self.salary.currency,
@@ -133,6 +139,8 @@ class Vacancy(VacancyData):
             city=getattr(model, "location_city", None),
             state=getattr(model, "location_state", None),
             country=getattr(model, "location_country", None),
+            lat=getattr(model, "location_lat", None),
+            lng=getattr(model, "location_lng", None),
         )
 
         salary = Salary(
@@ -183,6 +191,30 @@ class Vacancy(VacancyData):
         )
 
 # Feed object
+@dataclass
+class CustomMappingValue:
+    key: str
+    field: str
+    regex: str | None = None
+    preview: str | None = None
+
+
+@dataclass
+class CustomMapping:
+    return_pattern: str
+    values: List[CustomMappingValue]
+
+
+@dataclass
+class Mapping:
+    id: str
+    field: str
+    type: Literal['mapped', 'custom']
+    value: str | None = None
+    default: str | None = None
+    custom_mapping: CustomMapping | None = None
+
+
 class FeedInfo(ResolvableCompanyModel):
     id: UUID
     created_at: datetime
@@ -192,16 +224,17 @@ class FeedInfo(ResolvableCompanyModel):
     name: str
     status: str
     file_url: Optional[str]
+    entrypoint: Optional[str]
     ats_link: Optional[LinkInfo]
     source_type: str
     last_sync_date: Optional[datetime]
     synced_vacancy_count: int
-    mapping: dict
-    custom_fields: dict
+    mapping: List[Mapping]
+    custom_fields: List[Mapping]
 
     @staticmethod
     async def resolve_object(object_id: UUID, organization_id: UUID) -> "FeedInfo | None":
-        result = await ResolveClient.vacancies().get(f"feeds/{object_id}/resolve", headers={"X-Organization-ID": str(organization_id)})
+        result = await MSClient.vacancies().get(f"feeds/{object_id}/resolve", headers={"X-Organization-ID": str(organization_id)})
 
         if result.status_code != 200:
             return None
@@ -221,6 +254,7 @@ class FeedInfo(ResolvableCompanyModel):
             status=model.status,
             file_url=model.file_url,
             ats_link=ats_link,
+            entrypoint=model.entrypoint,
             source_type=model.source_type,
             last_sync_date=model.last_sync_date,
             synced_vacancy_count=model.synced_vacancy_count,
@@ -238,13 +272,14 @@ class FeedConfig(BaseModel):
     name: str
     status: str
     file_url: Optional[str]
+    entrypoint: Optional[str]
     source_type: str
     ats_link_id: Optional[UUID]
     last_sync_date: Optional[datetime]
     synced_vacancy_count: int
-    mapping: dict
-    custom_fields: dict
+    mapping: List[Mapping]
+    custom_fields: List[Mapping]
 
     @classmethod
     async def from_model(cls: "FeedConfig", model: FeedModel) -> "FeedConfig":
-        return cls(**model.model_dump())
\ No newline at end of file
+        return cls(**model.model_dump())
